#
# spec file for package deepin-start
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name       startdde
%define import_path github.com/linuxdeepin/startdde

Name:           deepin-start
Version:        5.9.49
Release:        4.1
Summary:        Starter of deepin desktop
License:        GPL-3.0-or-later
Group:          System/Daemons
URL:            https://github.com/linuxdeepin/startdde
Source0:        https://github.com/linuxdeepin/startdde/archive/%{version}/%{_name}-%{version}.tar.gz
Source1:        vendor.tar.gz
Source99:       deepin-start-rpmlintrc
# PATCH-FIX-OPENSUSE deepin-start-disable-gobuild-in-makefile.patch hillwood@opensuse.org
# Use gobuild macro instead of makefile to build go binaries
Patch0:         deepin-start-disable-gobuild-in-makefile.patch
%if 0%{?suse_version} > 1500
# PATCH-FIX-OPENSUSE workaround-dde-kwin-crash.patch hillwood@opensuse.org - Workaround the dde-kwin crash issue
Patch1:         workaround-dde-kwin-crash.patch
%endif
BuildRequires:  fdupes
BuildRequires:  golang-github-linuxdeepin-dde-api
BuildRequires:  golang-github-linuxdeepin-go-dbus-factory
BuildRequires:  golang-packaging
BuildRequires:  jq
BuildRequires:  xdg-user-dirs
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(gdk-3.0)
BuildRequires:  pkgconfig(gdk-pixbuf-xlib-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gnome-keyring-1)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(libcanberra)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libsecret-unstable)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xi)
Requires(post): update-alternatives
Requires:       deepin-daemon
# Requires:       libcgroup-tools
Provides:       startdde
AutoReqProv:    Off

%description
deepin-start is used for launching DDE components and invoking user's
custom applications which compliant with xdg autostart specification.

%package -n golang-github-linuxdeepin-startdde
Summary:        Startdde golang codes
Group:          Development/Languages/Golang
BuildArch:      noarch
Requires:       golang-github-linuxdeepin-dde-api
Requires:       golang-github-linuxdeepin-go-dbus-factory
AutoReq:        Off
%{go_provides}

%description -n golang-github-linuxdeepin-startdde
This package contains library source intended forbuilding other packages which
use import path with pkg.deepin.io/dde/startdde prefix.

%package lang
Summary:        Translations for package %{name}
Group:          System/Localization
Requires:       %{name} = %{version}
AutoReqProv:    Off

%description lang
Provides translations for the "%{name}" package.

%prep
%autosetup -p1 -a1 -n %{_name}-%{version}
%if 0%{?suse_version} > 1500
mkdir -p $HOME/rpmbuild/BUILD/%{name}-%{version}-build/go/src/
cp vendor/* $HOME/rpmbuild/BUILD/%{name}-%{version}-build/go/src/ -r
%else
mkdir -p $HOME/rpmbuild/BUILD/go/src/
cp vendor/* $HOME/rpmbuild/BUILD/go/src/ -r
%endif
rm -rf vendor

# Fix systemd path
sed -i 's|/lib/systemd|/usr/lib/systemd|g' Makefile

%build
export GO111MODULE=off
%goprep %{import_path}
%gobuild ...
%make_build

%install
%if 0%{?suse_version} > 1500
mv $HOME/rpmbuild/BUILD/%{name}-%{version}-build/go/src/github.com/linuxdeepin .
rm -rf $HOME/rpmbuild/BUILD/%{name}-%{version}-build/go/src/github.com/* \
       $HOME/rpmbuild/BUILD/%{name}-%{version}-build/go/src/golang.org \
       $HOME/rpmbuild/BUILD/%{name}-%{version}-build/go/src/gopkg.in
mv linuxdeepin $HOME/rpmbuild/BUILD/%{name}-%{version}-build/go/src/github.com/
%else
mv $HOME/rpmbuild/BUILD/go/src/github.com/linuxdeepin .
rm -rf $HOME/rpmbuild/BUILD/go/src/github.com/* \
       $HOME/rpmbuild/BUILD/go/src/golang.org \
       $HOME/rpmbuild/BUILD/go/src/gopkg.in
mv linuxdeepin $HOME/rpmbuild/BUILD/go/src/github.com/
%endif
%goinstall
%gosrc
%make_install
install -m0644 keyring/keyring.c %{buildroot}%{go_contribsrcdir}/%{import_path}/keyring/
install -m0644 iowait/xcursor_remap.c %{buildroot}%{go_contribsrcdir}/%{import_path}/iowait/
%gofilelist

install -d %{buildroot}%{_sbindir}
mv %{buildroot}%{_bindir}/fix-xauthority-perm %{buildroot}%{_sbindir}/deepin-fix-xauthority-perm
install -d %{buildroot}%{_prefix}/lib/deepin-daemon/
ln -sf %{_bindir}/greeter-display-daemon %{buildroot}%{_prefix}/lib/deepin-daemon/greeter-display-daemon
rm -rf %{buildroot}%{_datadir}/lightdm/

%fdupes %{buildroot}%{_datadir}
%find_lang startdde

%post
%{_sbindir}/update-alternatives --install %{_datadir}/xsessions/default.desktop \
  default-xsession.desktop %{_datadir}/xsessions/deepin.desktop 20

%postun
if [ ! -f %{_datadir}/xsessions/deepin.desktop ]; then
    %{_sbindir}/update-alternatives --remove default-xsession.desktop \
      %{_datadir}/xsessions/deepin.desktop
fi

%files
%doc README.md CHANGELOG.md
%license LICENSE
%{_bindir}/startdde
# %{_bindir}/wl_display_daemon
%{_bindir}/greeter-display-daemon
%{_sbindir}/deepin-fix-xauthority-perm
%{_datadir}/xsessions/deepin.desktop
%dir %{_datadir}/startdde
%{_datadir}/startdde/auto_launch.json
%{_datadir}/startdde/memchecker.json
%{_datadir}/startdde/*.conf
%{_datadir}/glib-2.0/schemas/com.deepin.*.xml
%dir %{_datadir}/dsg
%dir %{_datadir}/dsg/configs
%dir %{_datadir}/dsg/configs/org.deepin.startdde
%{_datadir}/dsg/configs/org.deepin.startdde/org.deepin.startdde.StartManager.json
%dir %{_prefix}/lib/deepin-daemon
%{_prefix}/lib/deepin-daemon/greeter-display-daemon
%config %{_sysconfdir}/profile.d/deepin-xdg-dir.sh
%config %{_sysconfdir}/X11/xinit/xinitrc.d/01deepin-profile
%config %{_sysconfdir}/X11/xinit/xinitrc.d/00deepin-dde-env
%config %{_sysconfdir}/X11/xinit/xinitrc.d/94qt_env

%files -n golang-github-linuxdeepin-startdde -f file.lst

%files lang -f startdde.lang

%changelog
* Fri Feb  7 2025 Hillwood Yang <hillwood@opensuse.org>
- Fix gopath for Tumbleweed
* Fri Jun 30 2023 Hillwood Yang <hillwood@opensuse.org>
- Update workaround-dde-kwin-crash.patch, use deepin-kwin
* Thu Oct 27 2022 Hillwood Yang <hillwood@opensuse.org>
- Add workaround-dde-kwin-crash.patch for Tumbleweed, Workaround the
  dde-kwin crash issue
* Thu Aug 25 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.9.49
  * Support DDCCI
  * Use systemd-scope to launch application
  * Fix bugs
* Wed Apr  6 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.9.15.1
  * Change pkg.deepin.io to github.com
  * use go env cmd
  * Add None mode for low-resolution tiling method
  * Fix bugs
* Tue Mar 15 2022 Hillwood Yang <hillwood@opensuse.org>
- Change license tag to GPL-3.0-or-later
* Wed Feb 23 2022 Hillwood Yang <hillwood@opensuse.org>
- Use last stable version of go to build
* Sat Feb 19 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.9.9.1
  * Add some api for wayland
  * Add custom-display-mode for wayland
  * Update translations
  * Fix bugs
* Tue Feb  1 2022 Hillwood Yang <hillwood@opensuse.org>
- Set deepin.desktop by xsessions default
* Wed Oct 27 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.8.31
  * Fix bugs
- Fix build on Leap 15.4+
* Sat Jul 24 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.8.22
  * Change go-dbus-factory struct as interface
  * Disable touchscreen when associated output disabled
  * Fix bugs
* Sat May 22 2021 Hillwood Yang <hillwood@opensuse.org>
- Keep golang version on 1.15 on Tumbleweed, the project does not support
  golang 1.16+
* Wed Apr  7 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.8.7
  * Fix crash bugs
  * Fix double screen bugs
* Wed Mar 10 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.8.4
  * Fix bugs
  * New GetExportedMethods method
* Sun Feb 21 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.6.0.14
  * feat: control qt program infos level
  * Fix bugs
  * add print_gopath in Makefile
* Mon Jan 27 2020 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.0.1
  * remove depends libgnome2-bin
  * change the dpms off order
  * Fix black screen when suspend/hibernate
  * set dpms off before reboot/shutdown
  * support loginctl lock/unlock-session
  * add task for dde-shutdown
* Thu Jul 18 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 3.14.7
  * feat: handle deepin-greeter missing qt-theme.ini
  * chore: do not set DEEPIN_WINE_SCALE in ~/.dde_env
  * feat(xsettings): set scale factor for deepin wine apps
  * fix(xsettings): send notification the first time auto set scale
  * feat: set ScaleLogicalDpi in qt-theme.ini
  * feat(xsettings): set Xft.dpi in x resources for wps
  * chore(xsettings): do not set Xft.dpi in RESOURCE_MANAGER
  * fix: kwin is not affected by the choice of dde-wm-chooser
* Sun May  5 2019 Hillwood Yang <hillwood@opensuse.org>
- Move lightdm.conf to lightdm-deepin-greeter
* Tue Apr 16 2019 Hillwood Yang <hillwood@opensuse.org>
- Rewrite spec with golang-packaging
- Update version to 3.14.2
  * fix: do not set recommended scale factor for qt app
  * chore: waiting for kwin after launch it
  * fix: not send SetScaleFactorDone signal
  * chore: update depends for wm
  * feat: set kwin compositing with com.deepin.wm
  * feat(watchdog): add task for kwin
  * feat: set screenScaleFactors to a number
  * feat: set scale factor for qt in a new way
  * chore: update build depends
  * fix(display): rotate the screen for the first time, then reset, but failed
  * feat: add wm_kwin.WMSwitcher for control kwin compositor
  * fix: bamfdaemon.service start request repeated too quickly
  * fix(display): cancel rotation, but the rotation of the touchpad is not restored
  * chore: `auto_launch/chinese.json` add dde-shutdown
  * feat: add check uid for lannch app and run cmd
  * fix: root window cursor is not `left_ptr` when use kwin as wm
  * fix: panic if getSavedBrightnessTable return nil map
  * feat: run kwin as wm if install package dde-kwin
  * feat: support monitor-dependent scaling
  * fix(display): connect an external monitor, give incorrect brightness value
  * feat: play login sound only when login automatically
  * change(api): session manager add method RunCommandWithOptions
  * feat(watchdog): SetLocked reset dde-lock task
  * chore(deb): remove dde-go-dbus-factory from build depends
  * chore: use go-dbus-factory
  * chore: use pkg.deepin.io/gir
  * fix(display): monitors config lost
  * feat: app proxy support google chrome
  * chore: set LANG and LANGUAGE for dbus daemon
  * feat(watchdog): add task for dde-lock
  * feat: limit ~/.dde-env only for deepin session
  * fix: can not play shutdown music
  * feat: do not save env in .pam_environment
  * feat: no use sys config allow switch
  * fix: modify the recommended scale factor calc
  * fix: if the speaker is muted, still play the logout music
  * feat(wm): Switcher add method AllowSwitch
  * fix: Qt double click not working well on hiDPI devices
  * feat: CanSuspend check file `/sys/power/mem_sleep` existence
  * chore: compile with sw arch no longer needs to use gccgo
  * fix: improve double clicks on touchscreen for Qt-based applications
  * feat(fix-xauthority-perm): create .Xauthority if not exist
  * feat: modify the meaning of allow switch
  * fix(xsettings): gtk window cursor size wrong
  * fix(display): the disconnected output still on
  * feat(display): add touchscreen rotation supported
  * fix(display): brightness setter auto is not good
  * fix(display): no listen xrandr event
  * chore: update changelog
  * fix: typo in `auto_launch/chinese.json`
  * chore: update changelog
  * chore: do not call gtk init
  * chore: `auto_launch/chinese.json` remove dde-control-center
  * chore: update changelog
  * fix: add booster-dtkwidget in auto launch chinese json
  * refactor: fix multiple typos
  * feat: run dde-welcome if deepin version changed
  * feat(wm): check wait for launcher wm
  * fix: typo in `auto_launch/chinese.json`
  * chore: do not call gtk init
  * chore: `auto_launch/chinese.json` remove dde-control-center
  * feat: run dde-welcome if deepin version changed
  * fix: add booster-dtkwidget in auto launch chinese json
  * refactor: fix multiple typos
  * fix(display): auto set scale factor to 2 in virtualbox
  * feat: allow session daemon run after dde-session-daemon part2 started
  * chore(debian): update build depends
  * fix: test failed in the pbuilder environment
  * feat: auto set scale factor
  * chore(display): rename setGammaSize to setOutputCrtcGamma
  * chore(display): err message include stderr
  * feat: support dde-session-daemon 2 step start
  * feat: launch dde-welcome by exec
  * feat: setup environment in startdde
  * fix(display): set brightness error typo
  * chore: no import lib xgb/proto
  * chore: use go-x11-client
  * chore: do not auto launch dde-file-manager on x86 arch
  * perf(swapsched): use less cpu when swapsched is not really enabled
  * feat(display): set default brightness of output to 1
  * fix(wm): select wm in dde-wm-chooser but it doesn't work
  * feat: add bin fix-xauthority-perm
  * chore: update build-depends
  * feat(wm): show osd after receive wm StartupReady signal
  * fix: can't log into session because of .Xauthority
  * feat(swapsched): check cgexec existence
  * chore: update makefile
  * chore: update makefile for arch `sw_64`
  * fix(keyring): `check_login` infinite loop
  * fix(swapsched): data race problem
  * fix(wm): fix genCardConfig when not found any video card
  * fix(watchdog): dde-polkit-agent running state check wrong
  * adjust `auto_launch.json`
  * fix: launch group
  * feat: wait wm launch
  * refactor: fix a typo
  * fix(debian): miss depends on libpam-gnome-keyring
  * refactor: refactor memchecker and memanalyzer
  * feat(swapsched): remove hard limit on DE group
  * feat: auto launch dde-control-center under mips64el
  * fix(wm): CurrentWM() return `unknown` if config file not found
  * feat(startManager): add method LaunchAppWithOptions
  * feat: add features switch for iowait and memchecker
  * fix(swapsched): cannot use sysStat.Dev (type uint32) as type uint64
  * fix: launchWait insufficient log information
  * feat(swapsched): use config of memchecker to configure swap sched dispatcher
  * chore: update memchecher min avail mem default value
  * refactor: improve memchecker debug
  * feat: add memanalyzer
  * fix: return nil if mem insufficient
  * fix: correct the action name
  * chore: fix config install path wrong
  * fix(memchecker): fix needed memory sum wrong
  * fix(memchecker): improve mem sufficient detect rule
  * refactor: refactor memchecker
  * fix(memchecker): fix warning dialog not showing again after close
  * refactor(memchecker): change the config path
  * feat: add memchecker for app launch
  * feat(watchdog): launch wm earlier after finding it dead
  * refactor: fix a typo
* Thu Mar 22 2018 hillwood@opensuse.org
- Update version to 3.1.26
  * fix: env var SSH_AUTH_SOCK not exported
  * fix: optimize channel statements
  * feat(swapsched): set blkio read write limit for apps supported
  * chore: update license
  * fix: make gnome-keyring-daemon no hang
  * fix(keyring): fix crash because of dbus no replies
  * fix(watchdog): update dde polkit agent determine methods
  * fix: make keyring inited on goroutinue
  * fix(display): fix refresh rate set wrong
  * fix: improve launch failed messages
  * chore: fix gccgo compile failure
  * feat: add keyring to init login
  * chore: optimize launch config
  * feat: use new lib gsettings
  * refactor: add auto launch config
  * feat: setup environment in script deepin-session
  * add deepin-session
  * feat: initialize gnome keyring daemon and components
  * feat: add iowait to indicate cpu status
* Thu Mar  1 2018 hillwood@opensuse.org
- Update version to 3.1.24
  * fix: Adapt lintian
  * play logout sound via ALSA
  * startManager: launched hook supported
  * remove dde-readahead
  * update depends
  * refactor sound theme player call
  * add DE Component processes to DE cgroup
  * startManager: desktop key X-Deepin-MaximumRAM supported
  * improve calculating limit of InActiveApps
  * limit ActiveApp's minimum rss limit
  * consider ActiveApp's swap usage and reversing kernel cache
  * limit maximum limit for reversing more cache RAM
  * startManager: launch DE app in DE cgroup
  * add wm switcher
  * startManager: add method GetApps
  * update links in README
  * fix radeon detect failure
  * remove the depend 'deepin-wm-switcher'
  * use lib cgroup
  * simplify cgroups check
  * swapsched: turn limits on or off dynamically
  * improve description of uiapp opened with RunCommand
  * modify ldflags args, fix debug version not work
  * add wm watcher in watchdog
  * fix compile failed using gccgo
  * wm: fix wm switch not work if config incomplete
  * swapsched: do not set soft limit for DE group
  * make xsettings as a package
  * add swap sched
  * launch app no scaling supported
  * startManager: fix method launch no files arg
  * refactor code about autostart
  * update makefile GOLDFLAGS
  * swap sched can control whether it is enabled in gsettings
* Fri Dec  1 2017 hillwood@opensuse.org
- Update to 3.1.22
  * Display: fix primary rect wrong after rotation
  * Display: sync primary settings from commandline
  * Disable logout sound if speaker muted
  * Fix(display): sync primary rectangle when apply changes
  * Fix primary rectangle wrong when output off
  * Correct deepin-wm-switcher config file path
  * Reap children processes
  * Remove sound event cache before playing
  * Launch deepin-notifications on session start
  * Brightness: only call displayBl.List once in init
  * Update soundutils event name
* Mon Nov 13 2017 hillwood@opensuse.org
- Cleanup spec.
  * Add Group tag
  * Fix %%pre* and %%post* scripts.
  * Fix suse-missing-rclink
* Tue Oct  3 2017 sensor.wen@gmail.com
- Initial package.
